#' mstDIF: A Collection of Statistical Tests for DIF Detection in Multistage Tests
#'
#' A Collection of Statistical Tests for the Detection of Differential
#' Item Functioning (DIF) in Multistage Tests. Methods entail logistic regression,
#' mstSIB, and various score-based tests.
#'
#' @keywords internal
"_PACKAGE"

